# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/campaign_experiment_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/campaign_experiment_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\034CampaignExperimentErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\nDgoogle/ads/googleads_v1/proto/errors/campaign_experiment_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\x80\x04\n\x1b\x43\x61mpaignExperimentErrorEnum\"\xe0\x03\n\x17\x43\x61mpaignExperimentError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x12\n\x0e\x44UPLICATE_NAME\x10\x02\x12\x16\n\x12INVALID_TRANSITION\x10\x03\x12/\n+CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET\x10\x04\x12\x36\n2CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN\x10\x05\x12\x33\n/CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT\x10\x06\x12%\n!CUSTOMER_CANNOT_CREATE_EXPERIMENT\x10\x07\x12%\n!CAMPAIGN_CANNOT_CREATE_EXPERIMENT\x10\x08\x12)\n%EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP\x10\t\x12\x38\n4EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION\x10\n\x12*\n&CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS\x10\x0b\x42\xf7\x01\n\"com.google.ads.googleads.v1.errorsB\x1c\x43\x61mpaignExperimentErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CAMPAIGNEXPERIMENTERRORENUM_CAMPAIGNEXPERIMENTERROR = _descriptor.EnumDescriptor(
  name='CampaignExperimentError',
  full_name='google.ads.googleads.v1.errors.CampaignExperimentErrorEnum.CampaignExperimentError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_NAME', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_TRANSITION', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_CANNOT_CREATE_EXPERIMENT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMPAIGN_CANNOT_CREATE_EXPERIMENT', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=167,
  serialized_end=647,
)
_sym_db.RegisterEnumDescriptor(_CAMPAIGNEXPERIMENTERRORENUM_CAMPAIGNEXPERIMENTERROR)


_CAMPAIGNEXPERIMENTERRORENUM = _descriptor.Descriptor(
  name='CampaignExperimentErrorEnum',
  full_name='google.ads.googleads.v1.errors.CampaignExperimentErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAMPAIGNEXPERIMENTERRORENUM_CAMPAIGNEXPERIMENTERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=647,
)

_CAMPAIGNEXPERIMENTERRORENUM_CAMPAIGNEXPERIMENTERROR.containing_type = _CAMPAIGNEXPERIMENTERRORENUM
DESCRIPTOR.message_types_by_name['CampaignExperimentErrorEnum'] = _CAMPAIGNEXPERIMENTERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignExperimentErrorEnum = _reflection.GeneratedProtocolMessageType('CampaignExperimentErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNEXPERIMENTERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.campaign_experiment_error_pb2'
  ,
  __doc__ = """Container for enum describing possible campaign experiment errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.CampaignExperimentErrorEnum)
  ))
_sym_db.RegisterMessage(CampaignExperimentErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/external_conversion_source.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/external_conversion_source.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB\035ExternalConversionSourceProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\nDgoogle/ads/googleads_v2/proto/enums/external_conversion_source.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"\x80\x04\n\x1c\x45xternalConversionSourceEnum\"\xdf\x03\n\x18\x45xternalConversionSource\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07WEBPAGE\x10\x02\x12\r\n\tANALYTICS\x10\x03\x12\n\n\x06UPLOAD\x10\x04\x12\x13\n\x0f\x41\x44_CALL_METRICS\x10\x05\x12\x18\n\x14WEBSITE_CALL_METRICS\x10\x06\x12\x10\n\x0cSTORE_VISITS\x10\x07\x12\x12\n\x0e\x41NDROID_IN_APP\x10\x08\x12\x0e\n\nIOS_IN_APP\x10\t\x12\x12\n\x0eIOS_FIRST_OPEN\x10\n\x12\x13\n\x0f\x41PP_UNSPECIFIED\x10\x0b\x12\x16\n\x12\x41NDROID_FIRST_OPEN\x10\x0c\x12\x10\n\x0cUPLOAD_CALLS\x10\r\x12\x0c\n\x08\x46IREBASE\x10\x0e\x12\x11\n\rCLICK_TO_CALL\x10\x0f\x12\x0e\n\nSALESFORCE\x10\x10\x12\x13\n\x0fSTORE_SALES_CRM\x10\x11\x12\x1f\n\x1bSTORE_SALES_PAYMENT_NETWORK\x10\x12\x12\x0f\n\x0bGOOGLE_PLAY\x10\x13\x12\x1d\n\x19THIRD_PARTY_APP_ANALYTICS\x10\x14\x12\x16\n\x12GOOGLE_ATTRIBUTION\x10\x15\x12\x16\n\x12STORE_SALES_DIRECT\x10\x16\x42\xf2\x01\n!com.google.ads.googleads.v2.enumsB\x1d\x45xternalConversionSourceProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_EXTERNALCONVERSIONSOURCEENUM_EXTERNALCONVERSIONSOURCE = _descriptor.EnumDescriptor(
  name='ExternalConversionSource',
  full_name='google.ads.googleads.v2.enums.ExternalConversionSourceEnum.ExternalConversionSource',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBPAGE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANALYTICS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPLOAD', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_CALL_METRICS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBSITE_CALL_METRICS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STORE_VISITS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANDROID_IN_APP', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS_IN_APP', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS_FIRST_OPEN', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APP_UNSPECIFIED', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANDROID_FIRST_OPEN', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPLOAD_CALLS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIREBASE', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLICK_TO_CALL', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SALESFORCE', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STORE_SALES_CRM', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STORE_SALES_PAYMENT_NETWORK', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_PLAY', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIRD_PARTY_APP_ANALYTICS', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_ATTRIBUTION', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STORE_SALES_DIRECT', index=22, number=22,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=167,
  serialized_end=646,
)
_sym_db.RegisterEnumDescriptor(_EXTERNALCONVERSIONSOURCEENUM_EXTERNALCONVERSIONSOURCE)


_EXTERNALCONVERSIONSOURCEENUM = _descriptor.Descriptor(
  name='ExternalConversionSourceEnum',
  full_name='google.ads.googleads.v2.enums.ExternalConversionSourceEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXTERNALCONVERSIONSOURCEENUM_EXTERNALCONVERSIONSOURCE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=646,
)

_EXTERNALCONVERSIONSOURCEENUM_EXTERNALCONVERSIONSOURCE.containing_type = _EXTERNALCONVERSIONSOURCEENUM
DESCRIPTOR.message_types_by_name['ExternalConversionSourceEnum'] = _EXTERNALCONVERSIONSOURCEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExternalConversionSourceEnum = _reflection.GeneratedProtocolMessageType('ExternalConversionSourceEnum', (_message.Message,), dict(
  DESCRIPTOR = _EXTERNALCONVERSIONSOURCEENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.external_conversion_source_pb2'
  ,
  __doc__ = """Container for enum describing the external conversion source that is
  associated with a ConversionAction.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.ExternalConversionSourceEnum)
  ))
_sym_db.RegisterMessage(ExternalConversionSourceEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.services import google_ads_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__service__pb2


class GoogleAdsServiceStub(object):
  """Proto file describing the GoogleAdsService.

  Service to fetch data and metrics across resources.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Search = channel.unary_unary(
        '/google.ads.googleads.v1.services.GoogleAdsService/Search',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__service__pb2.SearchGoogleAdsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__service__pb2.SearchGoogleAdsResponse.FromString,
        )
    self.Mutate = channel.unary_unary(
        '/google.ads.googleads.v1.services.GoogleAdsService/Mutate',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__service__pb2.MutateGoogleAdsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__service__pb2.MutateGoogleAdsResponse.FromString,
        )


class GoogleAdsServiceServicer(object):
  """Proto file describing the GoogleAdsService.

  Service to fetch data and metrics across resources.
  """

  def Search(self, request, context):
    """Returns all rows that match the search query.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Mutate(self, request, context):
    """Creates, updates, or removes resources. This method supports atomic
    transactions with multiple types of resources. For example, you can
    atomically create a campaign and a campaign budget, or perform up to
    thousands of mutates atomically.

    This method is essentially a wrapper around a series of mutate methods. The
    only features it offers over calling those methods directly are:
    - Atomic transactions
    - Temp resource names (described below)
    - Somewhat reduced latency over making a series of mutate calls.

    Note: Only resources that support atomic transactions are included, so this
    method can't replace all calls to individual services.

    ## Atomic Transaction Benefits

    Atomicity makes error handling much easier. If you're making a series of
    changes and one fails, it can leave your account in an inconsistent state.
    With atomicity, you either reach the desired state directly, or the request
    fails and you can retry.

    ## Temp Resource Names

    Temp resource names are a special type of resource name used to create a
    resource and reference that resource in the same request. For example, if a
    campaign budget is created with 'resource_name' equal to
    'customers/123/campaignBudgets/-1', that resource name can be reused in
    the 'Campaign.budget' field in the same request. That way, the two
    resources are created and linked atomically.

    To create a temp resource name, put a negative number in the part of the
    name that the server would normally allocate.

    Note:
    - Resources must be created with a temp name before the name can be reused.
    For example, the previous CampaignBudget+Campaign example would fail if
    the mutate order was reversed.
    - Temp names are not remembered across requests.
    - There's no limit to the number of temp names in a request.
    - Each temp name must use a unique negative number, even if the resource
    types differ.

    ## Latency

    It's important to group mutates by resource type or the request may time
    out and fail. Latency is roughly equal to a series of calls to individual
    mutate methods, where each change in resource type is a new call. For
    example, mutating 10 campaigns then 10 ad groups is like 2 calls, while
    mutating 1 campaign, 1 ad group, 1 campaign, 1 ad group is like 4 calls.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_GoogleAdsServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Search': grpc.unary_unary_rpc_method_handler(
          servicer.Search,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__service__pb2.SearchGoogleAdsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__service__pb2.SearchGoogleAdsResponse.SerializeToString,
      ),
      'Mutate': grpc.unary_unary_rpc_method_handler(
          servicer.Mutate,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__service__pb2.MutateGoogleAdsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_google__ads__service__pb2.MutateGoogleAdsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.GoogleAdsService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import customer_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__pb2
from google.ads.google_ads.v1.proto.services import customer_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2


class CustomerServiceStub(object):
  """Proto file describing the Customer service.

  Service to manage customers.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCustomer = channel.unary_unary(
        '/google.ads.googleads.v1.services.CustomerService/GetCustomer',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.GetCustomerRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__pb2.Customer.FromString,
        )
    self.MutateCustomer = channel.unary_unary(
        '/google.ads.googleads.v1.services.CustomerService/MutateCustomer',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.MutateCustomerRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.MutateCustomerResponse.FromString,
        )
    self.ListAccessibleCustomers = channel.unary_unary(
        '/google.ads.googleads.v1.services.CustomerService/ListAccessibleCustomers',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.ListAccessibleCustomersRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.ListAccessibleCustomersResponse.FromString,
        )
    self.CreateCustomerClient = channel.unary_unary(
        '/google.ads.googleads.v1.services.CustomerService/CreateCustomerClient',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.CreateCustomerClientRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.CreateCustomerClientResponse.FromString,
        )


class CustomerServiceServicer(object):
  """Proto file describing the Customer service.

  Service to manage customers.
  """

  def GetCustomer(self, request, context):
    """Returns the requested customer in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCustomer(self, request, context):
    """Updates a customer. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListAccessibleCustomers(self, request, context):
    """Returns resource names of customers directly accessible by the
    user authenticating the call.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateCustomerClient(self, request, context):
    """Creates a new client under manager. The new client customer is returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CustomerServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCustomer': grpc.unary_unary_rpc_method_handler(
          servicer.GetCustomer,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.GetCustomerRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_customer__pb2.Customer.SerializeToString,
      ),
      'MutateCustomer': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCustomer,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.MutateCustomerRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.MutateCustomerResponse.SerializeToString,
      ),
      'ListAccessibleCustomers': grpc.unary_unary_rpc_method_handler(
          servicer.ListAccessibleCustomers,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.ListAccessibleCustomersRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.ListAccessibleCustomersResponse.SerializeToString,
      ),
      'CreateCustomerClient': grpc.unary_unary_rpc_method_handler(
          servicer.CreateCustomerClient,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.CreateCustomerClientRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_customer__service__pb2.CreateCustomerClientResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.CustomerService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/conversion_action.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import tag_snippet_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_tag__snippet__pb2
from google.ads.google_ads.v1.proto.enums import attribution_model_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_attribution__model__pb2
from google.ads.google_ads.v1.proto.enums import conversion_action_category_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__category__pb2
from google.ads.google_ads.v1.proto.enums import conversion_action_counting_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__counting__type__pb2
from google.ads.google_ads.v1.proto.enums import conversion_action_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__status__pb2
from google.ads.google_ads.v1.proto.enums import conversion_action_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__type__pb2
from google.ads.google_ads.v1.proto.enums import data_driven_model_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_data__driven__model__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/conversion_action.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\025ConversionActionProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n?google/ads/googleads_v1/proto/resources/conversion_action.proto\x12!google.ads.googleads.v1.resources\x1a\x36google/ads/googleads_v1/proto/common/tag_snippet.proto\x1a;google/ads/googleads_v1/proto/enums/attribution_model.proto\x1a\x44google/ads/googleads_v1/proto/enums/conversion_action_category.proto\x1aIgoogle/ads/googleads_v1/proto/enums/conversion_action_counting_type.proto\x1a\x42google/ads/googleads_v1/proto/enums/conversion_action_status.proto\x1a@google/ads/googleads_v1/proto/enums/conversion_action_type.proto\x1a\x42google/ads/googleads_v1/proto/enums/data_driven_model_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xd4\x0c\n\x10\x43onversionAction\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12`\n\x06status\x18\x04 \x01(\x0e\x32P.google.ads.googleads.v1.enums.ConversionActionStatusEnum.ConversionActionStatus\x12Z\n\x04type\x18\x05 \x01(\x0e\x32L.google.ads.googleads.v1.enums.ConversionActionTypeEnum.ConversionActionType\x12\x66\n\x08\x63\x61tegory\x18\x06 \x01(\x0e\x32T.google.ads.googleads.v1.enums.ConversionActionCategoryEnum.ConversionActionCategory\x12\x34\n\x0eowner_customer\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x41\n\x1dinclude_in_conversions_metric\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n\"click_through_lookback_window_days\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!view_through_lookback_window_days\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12Y\n\x0evalue_settings\x18\x0b \x01(\x0b\x32\x41.google.ads.googleads.v1.resources.ConversionAction.ValueSettings\x12s\n\rcounting_type\x18\x0c \x01(\x0e\x32\\.google.ads.googleads.v1.enums.ConversionActionCountingTypeEnum.ConversionActionCountingType\x12p\n\x1a\x61ttribution_model_settings\x18\r \x01(\x0b\x32L.google.ads.googleads.v1.resources.ConversionAction.AttributionModelSettings\x12@\n\x0ctag_snippets\x18\x0e \x03(\x0b\x32*.google.ads.googleads.v1.common.TagSnippet\x12@\n\x1bphone_call_duration_seconds\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12,\n\x06\x61pp_id\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x1a\xed\x01\n\x18\x41ttributionModelSettings\x12_\n\x11\x61ttribution_model\x18\x01 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.AttributionModelEnum.AttributionModel\x12p\n\x18\x64\x61ta_driven_model_status\x18\x02 \x01(\x0e\x32N.google.ads.googleads.v1.enums.DataDrivenModelStatusEnum.DataDrivenModelStatus\x1a\xbf\x01\n\rValueSettings\x12\x33\n\rdefault_value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12;\n\x15\x64\x65\x66\x61ult_currency_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\x18\x61lways_use_default_value\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x82\x02\n%com.google.ads.googleads.v1.resourcesB\x15\x43onversionActionProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_tag__snippet__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_attribution__model__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__category__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__counting__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_data__driven__model__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CONVERSIONACTION_ATTRIBUTIONMODELSETTINGS = _descriptor.Descriptor(
  name='AttributionModelSettings',
  full_name='google.ads.googleads.v1.resources.ConversionAction.AttributionModelSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribution_model', full_name='google.ads.googleads.v1.resources.ConversionAction.AttributionModelSettings.attribution_model', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_driven_model_status', full_name='google.ads.googleads.v1.resources.ConversionAction.AttributionModelSettings.data_driven_model_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1818,
  serialized_end=2055,
)

_CONVERSIONACTION_VALUESETTINGS = _descriptor.Descriptor(
  name='ValueSettings',
  full_name='google.ads.googleads.v1.resources.ConversionAction.ValueSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_value', full_name='google.ads.googleads.v1.resources.ConversionAction.ValueSettings.default_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_currency_code', full_name='google.ads.googleads.v1.resources.ConversionAction.ValueSettings.default_currency_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='always_use_default_value', full_name='google.ads.googleads.v1.resources.ConversionAction.ValueSettings.always_use_default_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2058,
  serialized_end=2249,
)

_CONVERSIONACTION = _descriptor.Descriptor(
  name='ConversionAction',
  full_name='google.ads.googleads.v1.resources.ConversionAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.ConversionAction.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.ConversionAction.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.ConversionAction.name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.ConversionAction.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.resources.ConversionAction.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='google.ads.googleads.v1.resources.ConversionAction.category', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_customer', full_name='google.ads.googleads.v1.resources.ConversionAction.owner_customer', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_in_conversions_metric', full_name='google.ads.googleads.v1.resources.ConversionAction.include_in_conversions_metric', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='click_through_lookback_window_days', full_name='google.ads.googleads.v1.resources.ConversionAction.click_through_lookback_window_days', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_through_lookback_window_days', full_name='google.ads.googleads.v1.resources.ConversionAction.view_through_lookback_window_days', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_settings', full_name='google.ads.googleads.v1.resources.ConversionAction.value_settings', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counting_type', full_name='google.ads.googleads.v1.resources.ConversionAction.counting_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribution_model_settings', full_name='google.ads.googleads.v1.resources.ConversionAction.attribution_model_settings', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag_snippets', full_name='google.ads.googleads.v1.resources.ConversionAction.tag_snippets', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_call_duration_seconds', full_name='google.ads.googleads.v1.resources.ConversionAction.phone_call_duration_seconds', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='google.ads.googleads.v1.resources.ConversionAction.app_id', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONVERSIONACTION_ATTRIBUTIONMODELSETTINGS, _CONVERSIONACTION_VALUESETTINGS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=2249,
)

_CONVERSIONACTION_ATTRIBUTIONMODELSETTINGS.fields_by_name['attribution_model'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_attribution__model__pb2._ATTRIBUTIONMODELENUM_ATTRIBUTIONMODEL
_CONVERSIONACTION_ATTRIBUTIONMODELSETTINGS.fields_by_name['data_driven_model_status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_data__driven__model__status__pb2._DATADRIVENMODELSTATUSENUM_DATADRIVENMODELSTATUS
_CONVERSIONACTION_ATTRIBUTIONMODELSETTINGS.containing_type = _CONVERSIONACTION
_CONVERSIONACTION_VALUESETTINGS.fields_by_name['default_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CONVERSIONACTION_VALUESETTINGS.fields_by_name['default_currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONACTION_VALUESETTINGS.fields_by_name['always_use_default_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CONVERSIONACTION_VALUESETTINGS.containing_type = _CONVERSIONACTION
_CONVERSIONACTION.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONVERSIONACTION.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONACTION.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__status__pb2._CONVERSIONACTIONSTATUSENUM_CONVERSIONACTIONSTATUS
_CONVERSIONACTION.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__type__pb2._CONVERSIONACTIONTYPEENUM_CONVERSIONACTIONTYPE
_CONVERSIONACTION.fields_by_name['category'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__category__pb2._CONVERSIONACTIONCATEGORYENUM_CONVERSIONACTIONCATEGORY
_CONVERSIONACTION.fields_by_name['owner_customer'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONACTION.fields_by_name['include_in_conversions_metric'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CONVERSIONACTION.fields_by_name['click_through_lookback_window_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONVERSIONACTION.fields_by_name['view_through_lookback_window_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONVERSIONACTION.fields_by_name['value_settings'].message_type = _CONVERSIONACTION_VALUESETTINGS
_CONVERSIONACTION.fields_by_name['counting_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__action__counting__type__pb2._CONVERSIONACTIONCOUNTINGTYPEENUM_CONVERSIONACTIONCOUNTINGTYPE
_CONVERSIONACTION.fields_by_name['attribution_model_settings'].message_type = _CONVERSIONACTION_ATTRIBUTIONMODELSETTINGS
_CONVERSIONACTION.fields_by_name['tag_snippets'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_tag__snippet__pb2._TAGSNIPPET
_CONVERSIONACTION.fields_by_name['phone_call_duration_seconds'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONVERSIONACTION.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['ConversionAction'] = _CONVERSIONACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConversionAction = _reflection.GeneratedProtocolMessageType('ConversionAction', (_message.Message,), dict(

  AttributionModelSettings = _reflection.GeneratedProtocolMessageType('AttributionModelSettings', (_message.Message,), dict(
    DESCRIPTOR = _CONVERSIONACTION_ATTRIBUTIONMODELSETTINGS,
    __module__ = 'google.ads.googleads_v1.proto.resources.conversion_action_pb2'
    ,
    __doc__ = """Settings related to this conversion action's attribution model.
    
    
    Attributes:
        attribution_model:
            The attribution model type of this conversion action.
        data_driven_model_status:
            The status of the data-driven attribution model for the
            conversion action.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.ConversionAction.AttributionModelSettings)
    ))
  ,

  ValueSettings = _reflection.GeneratedProtocolMessageType('ValueSettings', (_message.Message,), dict(
    DESCRIPTOR = _CONVERSIONACTION_VALUESETTINGS,
    __module__ = 'google.ads.googleads_v1.proto.resources.conversion_action_pb2'
    ,
    __doc__ = """Settings related to the value for conversion events associated with this
    conversion action.
    
    
    Attributes:
        default_value:
            The value to use when conversion events for this conversion
            action are sent with an invalid, disallowed or missing value,
            or when this conversion action is configured to always use the
            default value.
        default_currency_code:
            The currency code to use when conversion events for this
            conversion action are sent with an invalid or missing currency
            code, or when this conversion action is configured to always
            use the default value.
        always_use_default_value:
            Controls whether the default value and default currency code
            are used in place of the value and currency code specified in
            conversion events for this conversion action.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.ConversionAction.ValueSettings)
    ))
  ,
  DESCRIPTOR = _CONVERSIONACTION,
  __module__ = 'google.ads.googleads_v1.proto.resources.conversion_action_pb2'
  ,
  __doc__ = """A conversion action.
  
  
  Attributes:
      resource_name:
          The resource name of the conversion action. Conversion action
          resource names have the form:  ``customers/{customer_id}/conve
          rsionActions/{conversion_action_id}``
      id:
          The ID of the conversion action.
      name:
          The name of the conversion action.  This field is required and
          should not be empty when creating new conversion actions.
      status:
          The status of this conversion action for conversion event
          accrual.
      type:
          The type of this conversion action.
      category:
          The category of conversions reported for this conversion
          action.
      owner_customer:
          The resource name of the conversion action owner customer, or
          null if this is a system-defined conversion action.
      include_in_conversions_metric:
          Whether this conversion action should be included in the
          "conversions" metric.
      click_through_lookback_window_days:
          The maximum number of days that may elapse between an
          interaction (e.g., a click) and a conversion event.
      view_through_lookback_window_days:
          The maximum number of days which may elapse between an
          impression and a conversion without an interaction.
      value_settings:
          Settings related to the value for conversion events associated
          with this conversion action.
      counting_type:
          How to count conversion events for the conversion action.
      attribution_model_settings:
          Settings related to this conversion action's attribution
          model.
      tag_snippets:
          The snippets used for tracking conversions.
      phone_call_duration_seconds:
          The phone call duration in seconds after which a conversion
          should be reported for this conversion action.  The value must
          be between 0 and 10000, inclusive.
      app_id:
          App ID for an app conversion action.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.ConversionAction)
  ))
_sym_db.RegisterMessage(ConversionAction)
_sym_db.RegisterMessage(ConversionAction.AttributionModelSettings)
_sym_db.RegisterMessage(ConversionAction.ValueSettings)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/feed_common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/feed_common.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\017FeedCommonProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n6google/ads/googleads_v1/proto/common/feed_common.proto\x12\x1egoogle.ads.googleads.v1.common\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"p\n\x05Money\x12\x33\n\rcurrency_code\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\ramount_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\xea\x01\n\"com.google.ads.googleads.v1.commonB\x0f\x46\x65\x65\x64\x43ommonProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_MONEY = _descriptor.Descriptor(
  name='Money',
  full_name='google.ads.googleads.v1.common.Money',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.ads.googleads.v1.common.Money.currency_code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount_micros', full_name='google.ads.googleads.v1.common.Money.amount_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=264,
)

_MONEY.fields_by_name['currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MONEY.fields_by_name['amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['Money'] = _MONEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Money = _reflection.GeneratedProtocolMessageType('Money', (_message.Message,), dict(
  DESCRIPTOR = _MONEY,
  __module__ = 'google.ads.googleads_v1.proto.common.feed_common_pb2'
  ,
  __doc__ = """Represents a price in a particular currency.
  
  
  Attributes:
      currency_code:
          Three-character ISO 4217 currency code.
      amount_micros:
          Amount in micros. One million is equivalent to one unit.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.Money)
  ))
_sym_db.RegisterMessage(Money)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import merchant_center_link_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_merchant__center__link__pb2
from google.ads.google_ads.v2.proto.services import merchant_center_link_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2


class MerchantCenterLinkServiceStub(object):
  """Proto file describing the MerchantCenterLink service.

  This service allows management of links between Google Ads and Google
  Merchant Center.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ListMerchantCenterLinks = channel.unary_unary(
        '/google.ads.googleads.v2.services.MerchantCenterLinkService/ListMerchantCenterLinks',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2.ListMerchantCenterLinksRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2.ListMerchantCenterLinksResponse.FromString,
        )
    self.GetMerchantCenterLink = channel.unary_unary(
        '/google.ads.googleads.v2.services.MerchantCenterLinkService/GetMerchantCenterLink',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2.GetMerchantCenterLinkRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_merchant__center__link__pb2.MerchantCenterLink.FromString,
        )
    self.MutateMerchantCenterLink = channel.unary_unary(
        '/google.ads.googleads.v2.services.MerchantCenterLinkService/MutateMerchantCenterLink',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2.MutateMerchantCenterLinkRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2.MutateMerchantCenterLinkResponse.FromString,
        )


class MerchantCenterLinkServiceServicer(object):
  """Proto file describing the MerchantCenterLink service.

  This service allows management of links between Google Ads and Google
  Merchant Center.
  """

  def ListMerchantCenterLinks(self, request, context):
    """Returns Merchant Center links available for this customer.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetMerchantCenterLink(self, request, context):
    """Returns the Merchant Center link in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateMerchantCenterLink(self, request, context):
    """Updates status or removes a Merchant Center link.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MerchantCenterLinkServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ListMerchantCenterLinks': grpc.unary_unary_rpc_method_handler(
          servicer.ListMerchantCenterLinks,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2.ListMerchantCenterLinksRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2.ListMerchantCenterLinksResponse.SerializeToString,
      ),
      'GetMerchantCenterLink': grpc.unary_unary_rpc_method_handler(
          servicer.GetMerchantCenterLink,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2.GetMerchantCenterLinkRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_merchant__center__link__pb2.MerchantCenterLink.SerializeToString,
      ),
      'MutateMerchantCenterLink': grpc.unary_unary_rpc_method_handler(
          servicer.MutateMerchantCenterLink,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2.MutateMerchantCenterLinkRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_merchant__center__link__service__pb2.MutateMerchantCenterLinkResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.MerchantCenterLinkService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import managed_placement_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_managed__placement__view__pb2
from google.ads.google_ads.v2.proto.services import managed_placement_view_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_managed__placement__view__service__pb2


class ManagedPlacementViewServiceStub(object):
  """Proto file describing the Managed Placement View service.

  Service to manage Managed Placement views.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetManagedPlacementView = channel.unary_unary(
        '/google.ads.googleads.v2.services.ManagedPlacementViewService/GetManagedPlacementView',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_managed__placement__view__service__pb2.GetManagedPlacementViewRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_managed__placement__view__pb2.ManagedPlacementView.FromString,
        )


class ManagedPlacementViewServiceServicer(object):
  """Proto file describing the Managed Placement View service.

  Service to manage Managed Placement views.
  """

  def GetManagedPlacementView(self, request, context):
    """Returns the requested Managed Placement view in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ManagedPlacementViewServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetManagedPlacementView': grpc.unary_unary_rpc_method_handler(
          servicer.GetManagedPlacementView,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_managed__placement__view__service__pb2.GetManagedPlacementViewRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_managed__placement__view__pb2.ManagedPlacementView.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.ManagedPlacementViewService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/common/segments.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v2.proto.enums import ad_network_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__network__type__pb2
from google.ads.google_ads.v2.proto.enums import click_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_click__type__pb2
from google.ads.google_ads.v2.proto.enums import conversion_action_category_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__action__category__pb2
from google.ads.google_ads.v2.proto.enums import conversion_attribution_event_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__attribution__event__type__pb2
from google.ads.google_ads.v2.proto.enums import conversion_lag_bucket_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__lag__bucket__pb2
from google.ads.google_ads.v2.proto.enums import conversion_or_adjustment_lag_bucket_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__or__adjustment__lag__bucket__pb2
from google.ads.google_ads.v2.proto.enums import day_of_week_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_day__of__week__pb2
from google.ads.google_ads.v2.proto.enums import device_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_device__pb2
from google.ads.google_ads.v2.proto.enums import external_conversion_source_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_external__conversion__source__pb2
from google.ads.google_ads.v2.proto.enums import hotel_date_selection_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__date__selection__type__pb2
from google.ads.google_ads.v2.proto.enums import hotel_price_bucket_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__price__bucket__pb2
from google.ads.google_ads.v2.proto.enums import hotel_rate_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__rate__type__pb2
from google.ads.google_ads.v2.proto.enums import month_of_year_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_month__of__year__pb2
from google.ads.google_ads.v2.proto.enums import placeholder_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2
from google.ads.google_ads.v2.proto.enums import product_channel_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__pb2
from google.ads.google_ads.v2.proto.enums import product_channel_exclusivity_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__exclusivity__pb2
from google.ads.google_ads.v2.proto.enums import product_condition_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__condition__pb2
from google.ads.google_ads.v2.proto.enums import search_engine_results_page_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__engine__results__page__type__pb2
from google.ads.google_ads.v2.proto.enums import search_term_match_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__term__match__type__pb2
from google.ads.google_ads.v2.proto.enums import slot_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_slot__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/common/segments.proto',
  package='google.ads.googleads.v2.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.commonB\rSegmentsProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Common\312\002\036Google\\Ads\\GoogleAds\\V2\\Common\352\002\"Google::Ads::GoogleAds::V2::Common'),
  serialized_pb=_b('\n3google/ads/googleads_v2/proto/common/segments.proto\x12\x1egoogle.ads.googleads.v2.common\x1a\x33google/ads/googleads_v2/proto/common/criteria.proto\x1a\x39google/ads/googleads_v2/proto/enums/ad_network_type.proto\x1a\x34google/ads/googleads_v2/proto/enums/click_type.proto\x1a\x44google/ads/googleads_v2/proto/enums/conversion_action_category.proto\x1aKgoogle/ads/googleads_v2/proto/enums/conversion_attribution_event_type.proto\x1a?google/ads/googleads_v2/proto/enums/conversion_lag_bucket.proto\x1aMgoogle/ads/googleads_v2/proto/enums/conversion_or_adjustment_lag_bucket.proto\x1a\x35google/ads/googleads_v2/proto/enums/day_of_week.proto\x1a\x30google/ads/googleads_v2/proto/enums/device.proto\x1a\x44google/ads/googleads_v2/proto/enums/external_conversion_source.proto\x1a\x43google/ads/googleads_v2/proto/enums/hotel_date_selection_type.proto\x1a<google/ads/googleads_v2/proto/enums/hotel_price_bucket.proto\x1a\x39google/ads/googleads_v2/proto/enums/hotel_rate_type.proto\x1a\x37google/ads/googleads_v2/proto/enums/month_of_year.proto\x1a:google/ads/googleads_v2/proto/enums/placeholder_type.proto\x1a\x39google/ads/googleads_v2/proto/enums/product_channel.proto\x1a\x45google/ads/googleads_v2/proto/enums/product_channel_exclusivity.proto\x1a;google/ads/googleads_v2/proto/enums/product_condition.proto\x1aIgoogle/ads/googleads_v2/proto/enums/search_engine_results_page_type.proto\x1a@google/ads/googleads_v2/proto/enums/search_term_match_type.proto\x1a.google/ads/googleads_v2/proto/enums/slot.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xb1*\n\x08Segments\x12W\n\x0f\x61\x64_network_type\x18\x03 \x01(\x0e\x32>.google.ads.googleads.v2.enums.AdNetworkTypeEnum.AdNetworkType\x12J\n\nclick_type\x18\x1a \x01(\x0e\x32\x36.google.ads.googleads.v2.enums.ClickTypeEnum.ClickType\x12\x37\n\x11\x63onversion_action\x18\x34 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12x\n\x1a\x63onversion_action_category\x18\x35 \x01(\x0e\x32T.google.ads.googleads.v2.enums.ConversionActionCategoryEnum.ConversionActionCategory\x12<\n\x16\x63onversion_action_name\x18\x36 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x15\x63onversion_adjustment\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x8b\x01\n!conversion_attribution_event_type\x18\x02 \x01(\x0e\x32`.google.ads.googleads.v2.enums.ConversionAttributionEventTypeEnum.ConversionAttributionEventType\x12i\n\x15\x63onversion_lag_bucket\x18\x32 \x01(\x0e\x32J.google.ads.googleads.v2.enums.ConversionLagBucketEnum.ConversionLagBucket\x12\x8f\x01\n#conversion_or_adjustment_lag_bucket\x18\x33 \x01(\x0e\x32\x62.google.ads.googleads.v2.enums.ConversionOrAdjustmentLagBucketEnum.ConversionOrAdjustmentLagBucket\x12*\n\x04\x64\x61te\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12K\n\x0b\x64\x61y_of_week\x18\x05 \x01(\x0e\x32\x36.google.ads.googleads.v2.enums.DayOfWeekEnum.DayOfWeek\x12@\n\x06\x64\x65vice\x18\x01 \x01(\x0e\x32\x30.google.ads.googleads.v2.enums.DeviceEnum.Device\x12x\n\x1a\x65xternal_conversion_source\x18\x37 \x01(\x0e\x32T.google.ads.googleads.v2.enums.ExternalConversionSourceEnum.ExternalConversionSource\x12\x38\n\x12geo_target_airport\x18\x41 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11geo_target_canton\x18L \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fgeo_target_city\x18> \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12geo_target_country\x18M \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11geo_target_county\x18\x44 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13geo_target_district\x18\x45 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10geo_target_metro\x18? \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12G\n!geo_target_most_specific_location\x18H \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\x16geo_target_postal_code\x18G \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13geo_target_province\x18K \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11geo_target_region\x18@ \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10geo_target_state\x18\x43 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x19hotel_booking_window_days\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x0fhotel_center_id\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x13hotel_check_in_date\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x1ahotel_check_in_day_of_week\x18\t \x01(\x0e\x32\x36.google.ads.googleads.v2.enums.DayOfWeekEnum.DayOfWeek\x12\x30\n\nhotel_city\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\x0bhotel_class\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x33\n\rhotel_country\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12s\n\x19hotel_date_selection_type\x18\r \x01(\x0e\x32P.google.ads.googleads.v2.enums.HotelDateSelectionTypeEnum.HotelDateSelectionType\x12\x39\n\x14hotel_length_of_stay\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x38\n\x12hotel_rate_rule_id\x18I \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12W\n\x0fhotel_rate_type\x18J \x01(\x0e\x32>.google.ads.googleads.v2.enums.HotelRateTypeEnum.HotelRateType\x12`\n\x12hotel_price_bucket\x18N \x01(\x0e\x32\x44.google.ads.googleads.v2.enums.HotelPriceBucketEnum.HotelPriceBucket\x12\x31\n\x0bhotel_state\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x04hour\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x41\n\x1dinteraction_on_this_extension\x18\x31 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x07keyword\x18= \x01(\x0b\x32\'.google.ads.googleads.v2.common.Keyword\x12+\n\x05month\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Q\n\rmonth_of_year\x18\x12 \x01(\x0e\x32:.google.ads.googleads.v2.enums.MonthOfYearEnum.MonthOfYear\x12\x36\n\x10partner_hotel_id\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\\\n\x10placeholder_type\x18\x14 \x01(\x0e\x32\x42.google.ads.googleads.v2.enums.PlaceholderTypeEnum.PlaceholderType\x12;\n\x15product_aggregator_id\x18\x1c \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x45\n\x1fproduct_bidding_category_level1\x18\x38 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x1fproduct_bidding_category_level2\x18\x39 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x1fproduct_bidding_category_level3\x18: \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x1fproduct_bidding_category_level4\x18; \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x45\n\x1fproduct_bidding_category_level5\x18< \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rproduct_brand\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Y\n\x0fproduct_channel\x18\x1e \x01(\x0e\x32@.google.ads.googleads.v2.enums.ProductChannelEnum.ProductChannel\x12{\n\x1bproduct_channel_exclusivity\x18\x1f \x01(\x0e\x32V.google.ads.googleads.v2.enums.ProductChannelExclusivityEnum.ProductChannelExclusivity\x12_\n\x11product_condition\x18  \x01(\x0e\x32\x44.google.ads.googleads.v2.enums.ProductConditionEnum.ProductCondition\x12\x35\n\x0fproduct_country\x18! \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19product_custom_attribute0\x18\" \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19product_custom_attribute1\x18# \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19product_custom_attribute2\x18$ \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19product_custom_attribute3\x18% \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x19product_custom_attribute4\x18& \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_item_id\x18\' \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10product_language\x18( \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13product_merchant_id\x18) \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x36\n\x10product_store_id\x18* \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rproduct_title\x18+ \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_type_l1\x18, \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_type_l2\x18- \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_type_l3\x18. \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_type_l4\x18/ \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fproduct_type_l5\x18\x30 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07quarter\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x83\x01\n\x1fsearch_engine_results_page_type\x18\x46 \x01(\x0e\x32Z.google.ads.googleads.v2.enums.SearchEngineResultsPageTypeEnum.SearchEngineResultsPageType\x12j\n\x16search_term_match_type\x18\x16 \x01(\x0e\x32J.google.ads.googleads.v2.enums.SearchTermMatchTypeEnum.SearchTermMatchType\x12:\n\x04slot\x18\x17 \x01(\x0e\x32,.google.ads.googleads.v2.enums.SlotEnum.Slot\x12-\n\x07webpage\x18\x42 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04week\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x04year\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"~\n\x07Keyword\x12\x38\n\x12\x61\x64_group_criterion\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x04info\x18\x02 \x01(\x0b\x32+.google.ads.googleads.v2.common.KeywordInfoB\xe8\x01\n\"com.google.ads.googleads.v2.commonB\rSegmentsProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Common\xea\x02\"Google::Ads::GoogleAds::V2::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__network__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_click__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__action__category__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__attribution__event__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__lag__bucket__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__or__adjustment__lag__bucket__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_day__of__week__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_device__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_external__conversion__source__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__date__selection__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__price__bucket__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__rate__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_month__of__year__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__exclusivity__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__condition__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__engine__results__page__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__term__match__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_slot__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_SEGMENTS = _descriptor.Descriptor(
  name='Segments',
  full_name='google.ads.googleads.v2.common.Segments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad_network_type', full_name='google.ads.googleads.v2.common.Segments.ad_network_type', index=0,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='click_type', full_name='google.ads.googleads.v2.common.Segments.click_type', index=1,
      number=26, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v2.common.Segments.conversion_action', index=2,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action_category', full_name='google.ads.googleads.v2.common.Segments.conversion_action_category', index=3,
      number=53, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action_name', full_name='google.ads.googleads.v2.common.Segments.conversion_action_name', index=4,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_adjustment', full_name='google.ads.googleads.v2.common.Segments.conversion_adjustment', index=5,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_attribution_event_type', full_name='google.ads.googleads.v2.common.Segments.conversion_attribution_event_type', index=6,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_lag_bucket', full_name='google.ads.googleads.v2.common.Segments.conversion_lag_bucket', index=7,
      number=50, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_or_adjustment_lag_bucket', full_name='google.ads.googleads.v2.common.Segments.conversion_or_adjustment_lag_bucket', index=8,
      number=51, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='google.ads.googleads.v2.common.Segments.date', index=9,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='day_of_week', full_name='google.ads.googleads.v2.common.Segments.day_of_week', index=10,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='google.ads.googleads.v2.common.Segments.device', index=11,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_conversion_source', full_name='google.ads.googleads.v2.common.Segments.external_conversion_source', index=12,
      number=55, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_airport', full_name='google.ads.googleads.v2.common.Segments.geo_target_airport', index=13,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_canton', full_name='google.ads.googleads.v2.common.Segments.geo_target_canton', index=14,
      number=76, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_city', full_name='google.ads.googleads.v2.common.Segments.geo_target_city', index=15,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_country', full_name='google.ads.googleads.v2.common.Segments.geo_target_country', index=16,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_county', full_name='google.ads.googleads.v2.common.Segments.geo_target_county', index=17,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_district', full_name='google.ads.googleads.v2.common.Segments.geo_target_district', index=18,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_metro', full_name='google.ads.googleads.v2.common.Segments.geo_target_metro', index=19,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_most_specific_location', full_name='google.ads.googleads.v2.common.Segments.geo_target_most_specific_location', index=20,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_postal_code', full_name='google.ads.googleads.v2.common.Segments.geo_target_postal_code', index=21,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_province', full_name='google.ads.googleads.v2.common.Segments.geo_target_province', index=22,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_region', full_name='google.ads.googleads.v2.common.Segments.geo_target_region', index=23,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_state', full_name='google.ads.googleads.v2.common.Segments.geo_target_state', index=24,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_booking_window_days', full_name='google.ads.googleads.v2.common.Segments.hotel_booking_window_days', index=25,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_center_id', full_name='google.ads.googleads.v2.common.Segments.hotel_center_id', index=26,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_check_in_date', full_name='google.ads.googleads.v2.common.Segments.hotel_check_in_date', index=27,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_check_in_day_of_week', full_name='google.ads.googleads.v2.common.Segments.hotel_check_in_day_of_week', index=28,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_city', full_name='google.ads.googleads.v2.common.Segments.hotel_city', index=29,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_class', full_name='google.ads.googleads.v2.common.Segments.hotel_class', index=30,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_country', full_name='google.ads.googleads.v2.common.Segments.hotel_country', index=31,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_date_selection_type', full_name='google.ads.googleads.v2.common.Segments.hotel_date_selection_type', index=32,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_length_of_stay', full_name='google.ads.googleads.v2.common.Segments.hotel_length_of_stay', index=33,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_rate_rule_id', full_name='google.ads.googleads.v2.common.Segments.hotel_rate_rule_id', index=34,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_rate_type', full_name='google.ads.googleads.v2.common.Segments.hotel_rate_type', index=35,
      number=74, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_price_bucket', full_name='google.ads.googleads.v2.common.Segments.hotel_price_bucket', index=36,
      number=78, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_state', full_name='google.ads.googleads.v2.common.Segments.hotel_state', index=37,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hour', full_name='google.ads.googleads.v2.common.Segments.hour', index=38,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interaction_on_this_extension', full_name='google.ads.googleads.v2.common.Segments.interaction_on_this_extension', index=39,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='google.ads.googleads.v2.common.Segments.keyword', index=40,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='month', full_name='google.ads.googleads.v2.common.Segments.month', index=41,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='month_of_year', full_name='google.ads.googleads.v2.common.Segments.month_of_year', index=42,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partner_hotel_id', full_name='google.ads.googleads.v2.common.Segments.partner_hotel_id', index=43,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_type', full_name='google.ads.googleads.v2.common.Segments.placeholder_type', index=44,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_aggregator_id', full_name='google.ads.googleads.v2.common.Segments.product_aggregator_id', index=45,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_level1', full_name='google.ads.googleads.v2.common.Segments.product_bidding_category_level1', index=46,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_level2', full_name='google.ads.googleads.v2.common.Segments.product_bidding_category_level2', index=47,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_level3', full_name='google.ads.googleads.v2.common.Segments.product_bidding_category_level3', index=48,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_level4', full_name='google.ads.googleads.v2.common.Segments.product_bidding_category_level4', index=49,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category_level5', full_name='google.ads.googleads.v2.common.Segments.product_bidding_category_level5', index=50,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_brand', full_name='google.ads.googleads.v2.common.Segments.product_brand', index=51,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_channel', full_name='google.ads.googleads.v2.common.Segments.product_channel', index=52,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_channel_exclusivity', full_name='google.ads.googleads.v2.common.Segments.product_channel_exclusivity', index=53,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_condition', full_name='google.ads.googleads.v2.common.Segments.product_condition', index=54,
      number=32, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_country', full_name='google.ads.googleads.v2.common.Segments.product_country', index=55,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_custom_attribute0', full_name='google.ads.googleads.v2.common.Segments.product_custom_attribute0', index=56,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_custom_attribute1', full_name='google.ads.googleads.v2.common.Segments.product_custom_attribute1', index=57,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_custom_attribute2', full_name='google.ads.googleads.v2.common.Segments.product_custom_attribute2', index=58,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_custom_attribute3', full_name='google.ads.googleads.v2.common.Segments.product_custom_attribute3', index=59,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_custom_attribute4', full_name='google.ads.googleads.v2.common.Segments.product_custom_attribute4', index=60,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_item_id', full_name='google.ads.googleads.v2.common.Segments.product_item_id', index=61,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_language', full_name='google.ads.googleads.v2.common.Segments.product_language', index=62,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_merchant_id', full_name='google.ads.googleads.v2.common.Segments.product_merchant_id', index=63,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_store_id', full_name='google.ads.googleads.v2.common.Segments.product_store_id', index=64,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_title', full_name='google.ads.googleads.v2.common.Segments.product_title', index=65,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type_l1', full_name='google.ads.googleads.v2.common.Segments.product_type_l1', index=66,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type_l2', full_name='google.ads.googleads.v2.common.Segments.product_type_l2', index=67,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type_l3', full_name='google.ads.googleads.v2.common.Segments.product_type_l3', index=68,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type_l4', full_name='google.ads.googleads.v2.common.Segments.product_type_l4', index=69,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type_l5', full_name='google.ads.googleads.v2.common.Segments.product_type_l5', index=70,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quarter', full_name='google.ads.googleads.v2.common.Segments.quarter', index=71,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_engine_results_page_type', full_name='google.ads.googleads.v2.common.Segments.search_engine_results_page_type', index=72,
      number=70, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_term_match_type', full_name='google.ads.googleads.v2.common.Segments.search_term_match_type', index=73,
      number=22, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slot', full_name='google.ads.googleads.v2.common.Segments.slot', index=74,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='webpage', full_name='google.ads.googleads.v2.common.Segments.webpage', index=75,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='week', full_name='google.ads.googleads.v2.common.Segments.week', index=76,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='year', full_name='google.ads.googleads.v2.common.Segments.year', index=77,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1469,
  serialized_end=6894,
)


_KEYWORD = _descriptor.Descriptor(
  name='Keyword',
  full_name='google.ads.googleads.v2.common.Keyword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad_group_criterion', full_name='google.ads.googleads.v2.common.Keyword.ad_group_criterion', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='google.ads.googleads.v2.common.Keyword.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6896,
  serialized_end=7022,
)

_SEGMENTS.fields_by_name['ad_network_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_ad__network__type__pb2._ADNETWORKTYPEENUM_ADNETWORKTYPE
_SEGMENTS.fields_by_name['click_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_click__type__pb2._CLICKTYPEENUM_CLICKTYPE
_SEGMENTS.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['conversion_action_category'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__action__category__pb2._CONVERSIONACTIONCATEGORYENUM_CONVERSIONACTIONCATEGORY
_SEGMENTS.fields_by_name['conversion_action_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['conversion_adjustment'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_SEGMENTS.fields_by_name['conversion_attribution_event_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__attribution__event__type__pb2._CONVERSIONATTRIBUTIONEVENTTYPEENUM_CONVERSIONATTRIBUTIONEVENTTYPE
_SEGMENTS.fields_by_name['conversion_lag_bucket'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__lag__bucket__pb2._CONVERSIONLAGBUCKETENUM_CONVERSIONLAGBUCKET
_SEGMENTS.fields_by_name['conversion_or_adjustment_lag_bucket'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_conversion__or__adjustment__lag__bucket__pb2._CONVERSIONORADJUSTMENTLAGBUCKETENUM_CONVERSIONORADJUSTMENTLAGBUCKET
_SEGMENTS.fields_by_name['date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['day_of_week'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_day__of__week__pb2._DAYOFWEEKENUM_DAYOFWEEK
_SEGMENTS.fields_by_name['device'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_device__pb2._DEVICEENUM_DEVICE
_SEGMENTS.fields_by_name['external_conversion_source'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_external__conversion__source__pb2._EXTERNALCONVERSIONSOURCEENUM_EXTERNALCONVERSIONSOURCE
_SEGMENTS.fields_by_name['geo_target_airport'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_canton'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_city'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_country'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_county'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_district'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_metro'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_most_specific_location'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_postal_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_province'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_region'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['geo_target_state'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hotel_booking_window_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SEGMENTS.fields_by_name['hotel_center_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SEGMENTS.fields_by_name['hotel_check_in_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hotel_check_in_day_of_week'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_day__of__week__pb2._DAYOFWEEKENUM_DAYOFWEEK
_SEGMENTS.fields_by_name['hotel_city'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hotel_class'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_SEGMENTS.fields_by_name['hotel_country'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hotel_date_selection_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__date__selection__type__pb2._HOTELDATESELECTIONTYPEENUM_HOTELDATESELECTIONTYPE
_SEGMENTS.fields_by_name['hotel_length_of_stay'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_SEGMENTS.fields_by_name['hotel_rate_rule_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hotel_rate_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__rate__type__pb2._HOTELRATETYPEENUM_HOTELRATETYPE
_SEGMENTS.fields_by_name['hotel_price_bucket'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_hotel__price__bucket__pb2._HOTELPRICEBUCKETENUM_HOTELPRICEBUCKET
_SEGMENTS.fields_by_name['hotel_state'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['hour'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_SEGMENTS.fields_by_name['interaction_on_this_extension'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_SEGMENTS.fields_by_name['keyword'].message_type = _KEYWORD
_SEGMENTS.fields_by_name['month'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['month_of_year'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_month__of__year__pb2._MONTHOFYEARENUM_MONTHOFYEAR
_SEGMENTS.fields_by_name['partner_hotel_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['placeholder_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2._PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE
_SEGMENTS.fields_by_name['product_aggregator_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_SEGMENTS.fields_by_name['product_bidding_category_level1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_bidding_category_level2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_bidding_category_level3'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_bidding_category_level4'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_bidding_category_level5'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_brand'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_channel'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__pb2._PRODUCTCHANNELENUM_PRODUCTCHANNEL
_SEGMENTS.fields_by_name['product_channel_exclusivity'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__channel__exclusivity__pb2._PRODUCTCHANNELEXCLUSIVITYENUM_PRODUCTCHANNELEXCLUSIVITY
_SEGMENTS.fields_by_name['product_condition'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_product__condition__pb2._PRODUCTCONDITIONENUM_PRODUCTCONDITION
_SEGMENTS.fields_by_name['product_country'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_custom_attribute0'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_custom_attribute1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_custom_attribute2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_custom_attribute3'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_custom_attribute4'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_item_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_language'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_merchant_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_SEGMENTS.fields_by_name['product_store_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_type_l1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_type_l2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_type_l3'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_type_l4'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['product_type_l5'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['quarter'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['search_engine_results_page_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__engine__results__page__type__pb2._SEARCHENGINERESULTSPAGETYPEENUM_SEARCHENGINERESULTSPAGETYPE
_SEGMENTS.fields_by_name['search_term_match_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_search__term__match__type__pb2._SEARCHTERMMATCHTYPEENUM_SEARCHTERMMATCHTYPE
_SEGMENTS.fields_by_name['slot'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_slot__pb2._SLOTENUM_SLOT
_SEGMENTS.fields_by_name['webpage'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['week'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEGMENTS.fields_by_name['year'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_KEYWORD.fields_by_name['ad_group_criterion'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORD.fields_by_name['info'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._KEYWORDINFO
DESCRIPTOR.message_types_by_name['Segments'] = _SEGMENTS
DESCRIPTOR.message_types_by_name['Keyword'] = _KEYWORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Segments = _reflection.GeneratedProtocolMessageType('Segments', (_message.Message,), dict(
  DESCRIPTOR = _SEGMENTS,
  __module__ = 'google.ads.googleads_v2.proto.common.segments_pb2'
  ,
  __doc__ = """Segment only fields.
  
  
  Attributes:
      ad_network_type:
          Ad network type.
      click_type:
          Click type.
      conversion_action:
          Resource name of the conversion action.
      conversion_action_category:
          Conversion action category.
      conversion_action_name:
          Conversion action name.
      conversion_adjustment:
          This segments your conversion columns by the original
          conversion and conversion value vs. the delta if conversions
          were adjusted. False row has the data as originally stated;
          While true row has the delta between data now and the data as
          originally stated. Summing the two together results post-
          adjustment data.
      conversion_attribution_event_type:
          Conversion attribution event type.
      conversion_lag_bucket:
          An enum value representing the number of days between the
          impression and the conversion.
      conversion_or_adjustment_lag_bucket:
          An enum value representing the number of days between the
          impression and the conversion or between the impression and
          adjustments to the conversion.
      date:
          Date to which metrics apply. yyyy-MM-dd format, e.g.,
          2018-04-17.
      day_of_week:
          Day of the week, e.g., MONDAY.
      device:
          Device to which metrics apply.
      external_conversion_source:
          External conversion source.
      geo_target_airport:
          Resource name of the geo target constant that represents an
          airport.
      geo_target_canton:
          Resource name of the geo target constant that represents a
          canton.
      geo_target_city:
          Resource name of the geo target constant that represents a
          city.
      geo_target_country:
          Resource name of the geo target constant that represents a
          country.
      geo_target_county:
          Resource name of the geo target constant that represents a
          county.
      geo_target_district:
          Resource name of the geo target constant that represents a
          district.
      geo_target_metro:
          Resource name of the geo target constant that represents a
          metro.
      geo_target_most_specific_location:
          Resource name of the geo target constant that represents the
          most specific location.
      geo_target_postal_code:
          Resource name of the geo target constant that represents a
          postal code.
      geo_target_province:
          Resource name of the geo target constant that represents a
          province.
      geo_target_region:
          Resource name of the geo target constant that represents a
          region.
      geo_target_state:
          Resource name of the geo target constant that represents a
          state.
      hotel_booking_window_days:
          Hotel booking window in days.
      hotel_center_id:
          Hotel center ID.
      hotel_check_in_date:
          Hotel check-in date. Formatted as yyyy-MM-dd.
      hotel_check_in_day_of_week:
          Hotel check-in day of week.
      hotel_city:
          Hotel city.
      hotel_class:
          Hotel class.
      hotel_country:
          Hotel country.
      hotel_date_selection_type:
          Hotel date selection type.
      hotel_length_of_stay:
          Hotel length of stay.
      hotel_rate_rule_id:
          Hotel rate rule ID.
      hotel_rate_type:
          Hotel rate type.
      hotel_price_bucket:
          Hotel price bucket.
      hotel_state:
          Hotel state.
      hour:
          Hour of day as a number between 0 and 23, inclusive.
      interaction_on_this_extension:
          Only used with feed item metrics. Indicates whether the
          interaction metrics occurred on the feed item itself or a
          different extension or ad unit.
      keyword:
          Keyword criterion.
      month:
          Month as represented by the date of the first day of a month.
          Formatted as yyyy-MM-dd.
      month_of_year:
          Month of the year, e.g., January.
      partner_hotel_id:
          Partner hotel ID.
      placeholder_type:
          Placeholder type. This is only used with feed item metrics.
      product_aggregator_id:
          Aggregator ID of the product.
      product_bidding_category_level1:
          Bidding category (level 1) of the product.
      product_bidding_category_level2:
          Bidding category (level 2) of the product.
      product_bidding_category_level3:
          Bidding category (level 3) of the product.
      product_bidding_category_level4:
          Bidding category (level 4) of the product.
      product_bidding_category_level5:
          Bidding category (level 5) of the product.
      product_brand:
          Brand of the product.
      product_channel:
          Channel of the product.
      product_channel_exclusivity:
          Channel exclusivity of the product.
      product_condition:
          Condition of the product.
      product_country:
          Resource name of the geo target constant for the country of
          sale of the product.
      product_custom_attribute0:
          Custom attribute 0 of the product.
      product_custom_attribute1:
          Custom attribute 1 of the product.
      product_custom_attribute2:
          Custom attribute 2 of the product.
      product_custom_attribute3:
          Custom attribute 3 of the product.
      product_custom_attribute4:
          Custom attribute 4 of the product.
      product_item_id:
          Item ID of the product.
      product_language:
          Resource name of the language constant for the language of the
          product.
      product_merchant_id:
          Merchant ID of the product.
      product_store_id:
          Store ID of the product.
      product_title:
          Title of the product.
      product_type_l1:
          Type (level 1) of the product.
      product_type_l2:
          Type (level 2) of the product.
      product_type_l3:
          Type (level 3) of the product.
      product_type_l4:
          Type (level 4) of the product.
      product_type_l5:
          Type (level 5) of the product.
      quarter:
          Quarter as represented by the date of the first day of a
          quarter. Uses the calendar year for quarters, e.g., the second
          quarter of 2018 starts on 2018-04-01. Formatted as yyyy-MM-dd.
      search_engine_results_page_type:
          Type of the search engine results page.
      search_term_match_type:
          Match type of the keyword that triggered the ad, including
          variants.
      slot:
          Position of the ad.
      webpage:
          Resource name of the ad group criterion that represents
          webpage criterion.
      week:
          Week as defined as Monday through Sunday, and represented by
          the date of Monday. Formatted as yyyy-MM-dd.
      year:
          Year, formatted as yyyy.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.Segments)
  ))
_sym_db.RegisterMessage(Segments)

Keyword = _reflection.GeneratedProtocolMessageType('Keyword', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORD,
  __module__ = 'google.ads.googleads_v2.proto.common.segments_pb2'
  ,
  __doc__ = """A Keyword criterion segment.
  
  
  Attributes:
      ad_group_criterion:
          The AdGroupCriterion resource name.
      info:
          Keyword info.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.Keyword)
  ))
_sym_db.RegisterMessage(Keyword)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
